/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Subject } from 'rxjs';
import { IconSettings } from './models';
import { SVGIcon } from '@progress/kendo-svg-icons';
import * as i0 from "@angular/core";
/**
 * Represents the service that manages icon settings.
 * Use the `notify` method to update icon settings dynamically.
 *
 * @example
 * ```typescript
 * constructor(private iconSettingsService: IconSettingsService) {}
 *
 * this.iconSettingsService.notify({ themeColor: 'primary' });
 * ```
 */
export declare class IconSettingsService {
    /**
     * @hidden
     */
    readonly changes: Subject<IconSettings>;
    /**
     * Notifies subscribers about changes in the icon settings.
     *
     * @param iconSettings - (Optional) Sets a new value for the [icon settings token]({% slug api_icons_icon_settings %}).
     * @example
     * ```typescript
     * iconSettingsService.notify({ size: 'large' });
     * ```
     */
    notify(iconSettings?: IconSettings): void;
    /**
     * Returns the [`SVGIcon`](slug:api_icons_svgicon) object for the provided key.
     * Override in a custom service to provide custom SVG icons.
     *
     * @hidden
     */
    getSvgIcon(_name: string): SVGIcon;
    /**
     * Returns the list of classes to be rendered on the host `SPAN` element of custom font icons.
     * Override in a custom service to provide classes for custom font icons.
     *
     * @hidden
     */
    getCustomFontIconClass(_key: string): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<IconSettingsService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<IconSettingsService>;
}
