/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { IconFlip } from "./flip";
import { IconType } from "./icon-type";
import { IconSize } from "./size";
import { IconThemeColor } from "./theme-color";
/**
 * Represents the icon settings for Kendo UI icons.
 * Use the `IconSettings` interface to set the icon `type`, `themeColor`, `size`, and `flip` direction.
 *
 * @example
 * ```typescript
 * const settings: IconSettings = {
 *   type: 'svg',
 *   themeColor: 'primary',
 *   size: 'large',
 *   flip: 'horizontal'
 * };
 * ```
 */
export interface IconSettings {
    /**
     * Sets the `type` of the icon.
     */
    type?: IconType;
    /**
     * Sets the `themeColor` of the icon.
     */
    themeColor?: IconThemeColor;
    /**
     * Sets the `size` of the icon.
     */
    size?: IconSize;
    /**
     * Sets the `flip` direction of the icon.
     */
    flip?: IconFlip;
}
