/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { IconComponent } from "./icon/icon.component";
import { SVGIconComponent } from "./svg-icon/svg-icon.component";
/**
 * Represents the utility array that contains all `KendoIcon`-related components and directives.
 *
 * @example
 * ```typescript
 * import { Component } from '@angular/core';
 * import { KENDO_ICON } from '@progress/kendo-angular-icons';
 *
 * @Component({
 *   selector: 'my-app',
 *   standalone: true,
 *   imports: [KENDO_ICON],
 *   template: `...`,
 * })
 * export class AppComponent {}
 * ```
 */
export declare const KENDO_ICON: readonly [typeof IconComponent];
/**
 * Represents the utility array that contains all `KendoSVGIcon`-related components and directives.
 *
 * @example
 * ```typescript
 * import { Component } from '@angular/core';
 * import { KENDO_SVGICON } from '@progress/kendo-angular-icons';
 *
 * @Component({
 *   selector: 'my-app',
 *   standalone: true,
 *   imports: [KENDO_SVGICON],
 *   template: `...`,
 * })
 * export class AppComponent {}
 * ```
 */
export declare const KENDO_SVGICON: readonly [typeof SVGIconComponent];
/**
 * Represents the utility array that contains all `@progress/kendo-angular-icons`-related components and directives.
 *
 * @example
 * ```typescript
 * import { Component, ViewEncapsulation } from '@angular/core';
 * import { KENDO_ICONS } from '@progress/kendo-angular-icons';
 *
 * @Component({
 *   selector: 'my-app',
 *   standalone: true,
 *   imports: [KENDO_ICONS],
 *   template: `...`,
 * })
 * export class AppComponent {}
 * ```
 */
export declare const KENDO_ICONS: readonly [typeof IconComponent, typeof SVGIconComponent];
